=== modified file 'bzrlib/export/zip_exporter.py'
--- bzrlib/export/zip_exporter.py	2006-09-23 16:53:08 +0000
+++ bzrlib/export/zip_exporter.py	2006-09-23 19:05:44 +0000
@@ -21,17 +21,18 @@
 import stat
 import zipfile
 
+from bzrlib import (
+    osutils,
+    )
 from bzrlib.trace import mutter
 
 
 # Windows expects this bit to be set in the 'external_attr' section
 # Or it won't consider the entry a directory
 ZIP_DIRECTORY_BIT = (1 << 4)
-_FILE_MODE = 0664
-_DIR_MODE = 0775
 
-_FILE_ATTR = stat.S_IFREG | _FILE_MODE
-_DIR_ATTR = stat.S_IFDIR | _DIR_MODE | ZIP_DIRECTORY_BIT
+_FILE_ATTR = stat.S_IFREG
+_DIR_ATTR = stat.S_IFDIR | ZIP_DIRECTORY_BIT
 
 
 def zip_exporter(tree, dest, root):
@@ -62,7 +63,9 @@
             file_id = ie.file_id
             mutter("  export {%s} kind %s to %s", file_id, ie.kind, dest)
 
-            filename = os.path.join(root, dp).encode('utf8')
+            # zipfile.ZipFile switches all paths to forward
+            # slashes anyway, so just stick with that.
+            filename = osutils.pathjoin(root, dp).encode('utf8')
             if ie.kind == "file":
                 zinfo = zipfile.ZipInfo(
                             filename=filename,
@@ -75,7 +78,7 @@
                 # to the zip routine that they are really directories and
                 # not just empty files.
                 zinfo = zipfile.ZipInfo(
-                            filename=filename + os.sep,
+                            filename=filename + '/',
                             date_time=now)
                 zinfo.compress_type = compression
                 zinfo.external_attr = _DIR_ATTR

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2006-09-23 16:53:08 +0000
+++ bzrlib/tests/blackbox/test_export.py	2006-09-23 19:05:44 +0000
@@ -111,14 +111,12 @@
         zfile = zipfile.ZipFile('test.zip')
         names = sorted(zfile.namelist())
 
-        if sys.platform == 'win32':
-            self.assertEqual(['test\\a', 'test\\b\\', 'test\\b\\c', 'test\\d\\'], names)
-        else:
-            self.assertEqual(['test/a', 'test/b/', 'test/b/c', 'test/d/'], names)
+        # even on win32, zipfile.ZipFile changes all names to use
+        # forward slashes
+        self.assertEqual(['test/a', 'test/b/', 'test/b/c', 'test/d/'], names)
 
-        file_attr = stat.S_IFREG | zip_exporter._FILE_MODE
-        dir_attr = (stat.S_IFDIR | zip_exporter._DIR_MODE
-                    | zip_exporter.ZIP_DIRECTORY_BIT)
+        file_attr = stat.S_IFREG
+        dir_attr = stat.S_IFDIR | zip_exporter.ZIP_DIRECTORY_BIT
 
         a_info = zfile.getinfo(names[0])
         self.assertEqual(file_attr, a_info.external_attr)

